@@ -184,6 +184,13 @@ newuoaControl <- function(npt=NULL,
   .ret
 }
 
+#' @export
+rxUiDeparse.newuoaControl <- function(object, var) {
+  .default <- newuoaControl()
+  .w <- .deparseDifferent(.default, object, "genRxControl")
+  .deparseFinal(.default, object, .w, var)
+}
+
 #' Get the newuoa family control
 #'
 #' @param env newuoa optimization environment
