@@ -18,7 +18,7 @@ test_that("Standard theo linCmt()", {
     })
   }
 
-  skip_if_not(rxode2parse::.linCmtSens())
+  skip_if_not(rxode2::.linCmtSensB())
 
   f <- nlmixr(one.cmt)
 
